package
Version:
v0.0.1
Opens a new window with list of versions in this module.
Published: Jan 27, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func RegisterCodec(codec Codec)
RegisterCodec 注册编解码器,供所有传输客户端和服务器使用。
Codec 定义编解码接口,用于序列化和反序列化消息。
实现必须线程安全,方法可能被并发调用。
GetCodec 根据内容子类型获取已注册的编解码器,未注册则返回 nil。
content-subtype 应为小写。
Source Files
¶
Directories
¶
|
|
|
|
|
|
Package proto 定义 protobuf 编解码器。
|
Package proto 定义 protobuf 编解码器。 |
|
|
|
|
|
|
|
|
|
Click to show internal directories.
Click to hide internal directories.